@@ -23,6 +23,8 @@
 # IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+""" Module for spool directory reading. """
+
 import os
 import fnmatch
 import logging
@@ -61,8 +63,11 @@ class BaseSpoolDirectoryReader(object):
         :param delete_on_close: Delete file after processing and a new one 
           has been opened. Default: False
         :param bookmarking: Enable bookmarking. Default: True
-        :param open_hook: Function to be called after a file is opened.
-        :param close_hook: Function to be called after a file is closed.
+        :param open_hook: Optional function to be called after a file is opened.
+        :param close_hook: Optional function to be called after a file
+          is closed.  This function will be called before the file is
+          deleted allowing the close hook to make a copy of the file
+          for archiving.
         """
 
         self.directory = directory
@@ -270,7 +275,7 @@ class Unified2RecordSpoolReader(BaseSpoolDirectoryReader):
             record = unified2.read_record(self.fileobj)
             if record:
                 self.set_bookmark(self.fileobj.tell())
-        except unified2.ShortReadError as err:
+        except unified2.ShortReadError:
             # We can ignore this, read_record would have reset the
             # pointer already.
             pass
@@ -293,7 +298,7 @@ class Unified2EventSpoolReader(BaseSpoolDirectoryReader):
         super(Unified2EventSpoolReader, self).__init__(
             directory, prefix, open_mode="rb", **kwargs)
         self.aggregator = unified2.EventAggregator()
-        self.timeout = 1
+        self.timeout = timeout
         self.last_record_read_ts = None
 
     def set_to_offset(self, offset):
